==> haskell-clientsession-0.9.2.0-57-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-clientsession.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 clientsession
version:              0.9.2.0
visibility:           public
id:                   clientsession-0.9.2.0-4ayf6xxAJkZE5Gx1zQLfcv
key:                  clientsession-0.9.2.0-4ayf6xxAJkZE5Gx1zQLfcv
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Felipe Lessa <felipe.lessa@gmail.com>

stability:            stable
homepage:             http://github.com/yesodweb/clientsession/tree/master
synopsis:             Securely store session data in a client-side cookie.
description:
    Achieves security through AES-CTR encryption and
    Skein-MAC-512-256 authentication.  Uses Base64
    encoding to avoid any issues with characters.

category:             Web
abi:                  d4fd9808eae11b01edf64e5514877f16
exposed:              True
exposed-modules:      Web.ClientSession
hidden-modules:       System.LookupEnv
import-dirs:          /usr/lib/ghc-9.4.8/site-local/clientsession-0.9.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/clientsession-0.9.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/clientsession-0.9.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-clientsession
hs-libraries:         HSclientsession-0.9.2.0-4ayf6xxAJkZE5Gx1zQLfcv
depends:
    base-4.17.2.1 base64-bytestring-1.2.1.0-20QKryWonJ0FfyBIVqw9dX
    bytestring-0.11.5.3 cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    crypto-api-0.13.3-L9US7GS3I02EI9rbQ94kVv
    cryptonite-0.30-L2if4IiisPzIt53eP0ABwC directory-1.3.7.1
    entropy-0.4.1.11-KgGl1Y7Pn5mDV1IyWdAGFR
    setenv-0.1.1.3-4A8zWxAPPDXC38ifNLvqMb
    skein-1.0.9.4-IMf7Sc4q30NJfXBuV1dHL9
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C

haddock-interfaces:
    /usr/share/doc/haskell-clientsession/html/clientsession.haddock

haddock-html:         /usr/share/doc/haskell-clientsession/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-clientsession-0.9.2.0-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-clientsession.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 clientsession
version:              0.9.2.0
visibility:           public
id:                   clientsession-0.9.2.0-GSmhzvB6LHA65VE2XMNPs0
key:                  clientsession-0.9.2.0-GSmhzvB6LHA65VE2XMNPs0
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Felipe Lessa <felipe.lessa@gmail.com>

stability:            stable
homepage:             http://github.com/yesodweb/clientsession/tree/master
synopsis:             Securely store session data in a client-side cookie.
description:
    Achieves security through AES-CTR encryption and
    Skein-MAC-512-256 authentication.  Uses Base64
    encoding to avoid any issues with characters.

category:             Web
abi:                  54ae9e454fd460678298308a1b3332b5
exposed:              True
exposed-modules:      Web.ClientSession
hidden-modules:       System.LookupEnv
import-dirs:          /usr/lib/ghc-9.4.8/site-local/clientsession-0.9.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/clientsession-0.9.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/clientsession-0.9.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-clientsession
hs-libraries:         HSclientsession-0.9.2.0-GSmhzvB6LHA65VE2XMNPs0
depends:
    base-4.17.2.1 base64-bytestring-1.2.1.0-9p4vtkAuTQ4GHdtuHWxZHU
    bytestring-0.11.5.3 cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    crypto-api-0.13.3-L9US7GS3I02EI9rbQ94kVv
    cryptonite-0.30-9aiao6Baet5LbFVZqeOgvR directory-1.3.7.1
    entropy-0.4.1.11-KgGl1Y7Pn5mDV1IyWdAGFR
    setenv-0.1.1.3-4A8zWxAPPDXC38ifNLvqMb
    skein-1.0.9.4-IMf7Sc4q30NJfXBuV1dHL9
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C

haddock-interfaces:
    /usr/share/doc/haskell-clientsession/html/clientsession.haddock

haddock-html:         /usr/share/doc/haskell-clientsession/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
